@@ -852,7 +852,7 @@ static gboolean real_save_png (GdkPixbuf        *pixbuf,
                        if (strncmp (*kiter, "tEXt::", 6) == 0) {
                                gchar  *key = *kiter + 6;
                                int     len = strlen (key);
-                               if (len <= 1 || len > 79) {
+                               if (len < 1 || len > 79) {
                                        g_set_error_literal (error,
                                                             GDK_PIXBUF_ERROR,
                                                             GDK_PIXBUF_ERROR_BAD_OPTION,
@@ -1101,24 +1101,24 @@ MODULE_ENTRY (fill_vtable) (GdkPixbufModule *module)
 
 MODULE_ENTRY (fill_info) (GdkPixbufFormat *info)
 {
-        static GdkPixbufModulePattern signature[] = {
+        static const GdkPixbufModulePattern signature[] = {
                 { "\x89PNG\r\n\x1a\x0a", NULL, 100 },
                 { NULL, NULL, 0 }
         };
-	static gchar * mime_types[] = {
+	static const gchar *mime_types[] = {
 		"image/png",
 		NULL
 	};
-	static gchar * extensions[] = {
+	static const gchar *extensions[] = {
 		"png",
 		NULL
 	};
 
 	info->name = "png";
-        info->signature = signature;
+        info->signature = (GdkPixbufModulePattern *) signature;
 	info->description = N_("The PNG image format");
-	info->mime_types = mime_types;
-	info->extensions = extensions;
+	info->mime_types = (gchar **) mime_types;
+	info->extensions = (gchar **) extensions;
 	info->flags = GDK_PIXBUF_FORMAT_WRITABLE | GDK_PIXBUF_FORMAT_THREADSAFE;
 	info->license = "LGPL";
 }
